@@ -44,9 +44,6 @@
 #include <getopt.h>
 #include <inttypes.h>
 #include <ctype.h>
-#ifdef ENABLE_NLS
-#include <locale.h>
-#endif
 #include <byteswap.h>
 
 #define ALSA_PCM_NEW_HW_PARAMS_API
@@ -59,6 +56,10 @@
 #include "gettext.h"
 #include "version.h"
 
+#ifdef ENABLE_NLS
+#include <locale.h>
+#endif
+
 enum {
   TEST_PINK_NOISE = 1,
   TEST_SINE,
@@ -83,7 +84,7 @@ static snd_pcm_uframes_t  period_size;
 static const char *given_test_wav_file = NULL;
 static char *wav_file_dir = SOUNDSDIR;
 
-static const char        *channel_name[MAX_CHANNELS] = {
+static const char *const channel_name[MAX_CHANNELS] = {
   N_("Front Left"),
   N_("Front Right"),
   N_("Rear Left"),
@@ -250,12 +251,9 @@ static void generate_pink_noise( uint8_t *frames, int channel, int count) {
   double   res;
   int      chn;
   int32_t  ires;
-  float    fres;
   int8_t  *samp8 = (int8_t*) frames;
   int16_t *samp16 = (int16_t*) frames;
   int32_t *samp32 = (int32_t*) frames;
-  float   *samp_f = (float*) frames;
-  int sample_size_bits = snd_pcm_format_width(format); 
 
   while (count-- > 0) {
     for(chn=0;chn<channels;chn++) {
@@ -424,6 +422,14 @@ static int set_hwparams(snd_pcm_t *handle, snd_pcm_hw_params_t *params, snd_pcm_
       return err;
     }
   }
+
+  /* write the parameters to device */
+  err = snd_pcm_hw_params(handle, params);
+  if (err < 0) {
+    fprintf(stderr, _("Unable to set hw params for playback: %s\n"), snd_strerror(err));
+    return err;
+  }
+
   snd_pcm_hw_params_get_buffer_size(params, &buffer_size);
   snd_pcm_hw_params_get_period_size(params, &period_size, NULL);
   printf(_("was set period_size = %lu\n"),period_size);
@@ -433,13 +439,6 @@ static int set_hwparams(snd_pcm_t *handle, snd_pcm_hw_params_t *params, snd_pcm_
     return -EINVAL;
   }
 
-  /* write the parameters to device */
-  err = snd_pcm_hw_params(handle, params);
-  if (err < 0) {
-    fprintf(stderr, _("Unable to set hw params for playback: %s\n"), snd_strerror(err));
-    return err;
-  }
-
   return 0;
 }
 
@@ -622,7 +621,7 @@ static int check_wav_file(int channel, const char *name)
 
 static int setup_wav_file(int chn)
 {
-  static const char *wavs[MAX_CHANNELS] = {
+  static const char *const wavs[MAX_CHANNELS] = {
     "Front_Left.wav",
     "Front_Right.wav",
     "Rear_Left.wav",
@@ -804,7 +803,7 @@ int main(int argc, char *argv[]) {
   unsigned int		n, nloops;
   struct   timeval	tv1,tv2;
 
-  struct option         long_option[] = {
+  static const struct option long_option[] = {
     {"help",      0, NULL, 'h'},
     {"device",    1, NULL, 'D'},
     {"rate",      1, NULL, 'r'},
